import { defineEventHandler, readBody, setResponseStatus } from "h3";

import { checkIsImportedProduct } from "../../orders.post";
import { getImportedProducts, orderExists } from "../[id].get";
import Snowflake from "~/utils/snowflake";
import { database } from "~/server/utils/database";

import { createError } from "#imports";

export default defineEventHandler(async (e) => {
  const body = await readBody(e);
  const idOrder = e.context.params?.id as string;
  const idImportedProducts = new Snowflake().toString();

  if (!orderExists(idOrder)) throw createError({ statusCode: 404 });
  if (!checkIsImportedProduct(body, false)) throw createError({ message: "Invalid body", statusCode: 400 });

  await database.query(
    ["INSERT INTO",
      "`imported_products`",
      "VALUES",
      "(?, ?, ?, ?, ?, ?)",
    ].join(" "),
    [idImportedProducts, idOrder, body.name, body.link, body.price_imported, body.price],
  );

  setResponseStatus(e, 201);
  return getImportedProducts(idOrder);
});
