import { defineEventHandler, readBody, setResponseStatus } from "h3";

import { checkIsWork } from "../../orders.post";
import { getWork, orderExists } from "../[id].get";
import Snowflake from "~/utils/snowflake";
import { database } from "~/server/utils/database";

import { createError } from "#imports";

export default defineEventHandler(async (e) => {
  const body = await readBody(e);
  const idOrder = e.context.params?.id as string;
  const idWork = new Snowflake().toString();

  if (!orderExists(idOrder)) throw createError({ statusCode: 404 });
  if (!checkIsWork(body, false)) throw createError({ message: "Invalid body", statusCode: 400 });

  await database.query(
    ["INSERT INTO",
      "`work`",
      "VALUES",
      "(?, ?, ?, ?, ?, ?)",
    ].join(" "),
    [idWork, idOrder, body.offer, body.price, body.notes, body.is_fulfilled],
  );

  setResponseStatus(e, 201);

  return getWork(idWork);
});
